@@ -1,13 +1,17 @@
 from .exception_handling import ExceptionHandlingPlugin
 from .html_tags_stripper import HTMLTagStripperPlugin
 from .normalize_string import NormalizeStringPlugin
+from .opengraph_fill import OpenGraphFillPlugin
 from .opengraph_image_fetch import OpenGraphImageFetchPlugin
 from .schemaorg_fill import SchemaOrgFillPlugin
+from .static_values import StaticValueExceptionHandlingPlugin
 
 __all__ = [
     "ExceptionHandlingPlugin",
+    "StaticValueExceptionHandlingPlugin",
     "HTMLTagStripperPlugin",
     "NormalizeStringPlugin",
     "OpenGraphImageFetchPlugin",
+    "OpenGraphFillPlugin",
     "SchemaOrgFillPlugin",
 ]
