@@ -1,6 +1,5 @@
-# mypy: allow-untyped-defs
-
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 from ._utils import normalize_string
 
 
@@ -12,6 +11,13 @@ class Yummly(AbstractScraper):
     def author(self):
         return self.soup.find("a", {"class": "markdown-link"}).get_text()
 
+    def site_name(self):
+        title = self.soup.find("title")
+        if not title:
+            raise StaticValueException(return_value="Yummly")
+        _recipe, _delimiter, site_name = title.text.rpartition("|")
+        return site_name.lstrip()
+
     def ingredients(self):
         ingredients = self.soup.findAll("li", {"class": "IngredientLine"})
 
